/****************************************************************************
** Meta object code from reading C++ file 'qtoolbar_hook.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/qtoolbar_hook.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtoolbar_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QToolBar_hook_t {
    QByteArrayData data[22];
    char stringdata0[342];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QToolBar_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QToolBar_hook_t qt_meta_stringdata_QToolBar_hook = {
    {
QT_MOC_LITERAL(0, 0, 13), // "QToolBar_hook"
QT_MOC_LITERAL(1, 14, 20), // "actionTriggered_hook"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 8), // "QAction*"
QT_MOC_LITERAL(4, 45, 6), // "action"
QT_MOC_LITERAL(5, 52, 19), // "movableChanged_hook"
QT_MOC_LITERAL(6, 72, 7), // "movable"
QT_MOC_LITERAL(7, 80, 24), // "allowedAreasChanged_hook"
QT_MOC_LITERAL(8, 105, 16), // "Qt::ToolBarAreas"
QT_MOC_LITERAL(9, 122, 12), // "allowedAreas"
QT_MOC_LITERAL(10, 135, 23), // "orientationChanged_hook"
QT_MOC_LITERAL(11, 159, 15), // "Qt::Orientation"
QT_MOC_LITERAL(12, 175, 11), // "orientation"
QT_MOC_LITERAL(13, 187, 20), // "iconSizeChanged_hook"
QT_MOC_LITERAL(14, 208, 8), // "iconSize"
QT_MOC_LITERAL(15, 217, 27), // "toolButtonStyleChanged_hook"
QT_MOC_LITERAL(16, 245, 19), // "Qt::ToolButtonStyle"
QT_MOC_LITERAL(17, 265, 15), // "toolButtonStyle"
QT_MOC_LITERAL(18, 281, 20), // "topLevelChanged_hook"
QT_MOC_LITERAL(19, 302, 8), // "topLevel"
QT_MOC_LITERAL(20, 311, 22), // "visibilityChanged_hook"
QT_MOC_LITERAL(21, 334, 7) // "visible"

    },
    "QToolBar_hook\0actionTriggered_hook\0\0"
    "QAction*\0action\0movableChanged_hook\0"
    "movable\0allowedAreasChanged_hook\0"
    "Qt::ToolBarAreas\0allowedAreas\0"
    "orientationChanged_hook\0Qt::Orientation\0"
    "orientation\0iconSizeChanged_hook\0"
    "iconSize\0toolButtonStyleChanged_hook\0"
    "Qt::ToolButtonStyle\0toolButtonStyle\0"
    "topLevelChanged_hook\0topLevel\0"
    "visibilityChanged_hook\0visible"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QToolBar_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x08 /* Private */,
       5,    1,   57,    2, 0x08 /* Private */,
       7,    1,   60,    2, 0x08 /* Private */,
      10,    1,   63,    2, 0x08 /* Private */,
      13,    1,   66,    2, 0x08 /* Private */,
      15,    1,   69,    2, 0x08 /* Private */,
      18,    1,   72,    2, 0x08 /* Private */,
      20,    1,   75,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, QMetaType::QSize,   14,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void, QMetaType::Bool,   21,

       0        // eod
};

void QToolBar_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QToolBar_hook *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->actionTriggered_hook((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 1: _t->movableChanged_hook((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->allowedAreasChanged_hook((*reinterpret_cast< Qt::ToolBarAreas(*)>(_a[1]))); break;
        case 3: _t->orientationChanged_hook((*reinterpret_cast< Qt::Orientation(*)>(_a[1]))); break;
        case 4: _t->iconSizeChanged_hook((*reinterpret_cast< const QSize(*)>(_a[1]))); break;
        case 5: _t->toolButtonStyleChanged_hook((*reinterpret_cast< Qt::ToolButtonStyle(*)>(_a[1]))); break;
        case 6: _t->topLevelChanged_hook((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->visibilityChanged_hook((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QToolBar_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget_hook::staticMetaObject>(),
    qt_meta_stringdata_QToolBar_hook.data,
    qt_meta_data_QToolBar_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QToolBar_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QToolBar_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QToolBar_hook.stringdata0))
        return static_cast<void*>(this);
    return QWidget_hook::qt_metacast(_clname);
}

int QToolBar_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
