/****************************************************************************
** Meta object code from reading C++ file 'qprocess_hook.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/qprocess_hook.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qprocess_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QProcessEnvironment_hook_t {
    QByteArrayData data[1];
    char stringdata0[25];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QProcessEnvironment_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QProcessEnvironment_hook_t qt_meta_stringdata_QProcessEnvironment_hook = {
    {
QT_MOC_LITERAL(0, 0, 24) // "QProcessEnvironment_hook"

    },
    "QProcessEnvironment_hook"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QProcessEnvironment_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QProcessEnvironment_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QProcessEnvironment_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_meta_stringdata_QProcessEnvironment_hook.data,
    qt_meta_data_QProcessEnvironment_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QProcessEnvironment_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QProcessEnvironment_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QProcessEnvironment_hook.stringdata0))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QProcessEnvironment_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_QProcess_hook_t {
    QByteArrayData data[16];
    char stringdata0[242];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QProcess_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QProcess_hook_t qt_meta_stringdata_QProcess_hook = {
    {
QT_MOC_LITERAL(0, 0, 13), // "QProcess_hook"
QT_MOC_LITERAL(1, 14, 12), // "started_hook"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 13), // "finished_hook"
QT_MOC_LITERAL(4, 42, 8), // "exitCode"
QT_MOC_LITERAL(5, 51, 14), // "finished2_hook"
QT_MOC_LITERAL(6, 66, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(7, 87, 10), // "exitStatus"
QT_MOC_LITERAL(8, 98, 10), // "error_hook"
QT_MOC_LITERAL(9, 109, 22), // "QProcess::ProcessError"
QT_MOC_LITERAL(10, 132, 5), // "error"
QT_MOC_LITERAL(11, 138, 17), // "stateChanged_hook"
QT_MOC_LITERAL(12, 156, 22), // "QProcess::ProcessState"
QT_MOC_LITERAL(13, 179, 5), // "state"
QT_MOC_LITERAL(14, 185, 28), // "readyReadStandardOutput_hook"
QT_MOC_LITERAL(15, 214, 27) // "readyReadStandardError_hook"

    },
    "QProcess_hook\0started_hook\0\0finished_hook\0"
    "exitCode\0finished2_hook\0QProcess::ExitStatus\0"
    "exitStatus\0error_hook\0QProcess::ProcessError\0"
    "error\0stateChanged_hook\0QProcess::ProcessState\0"
    "state\0readyReadStandardOutput_hook\0"
    "readyReadStandardError_hook"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QProcess_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x08 /* Private */,
       3,    1,   50,    2, 0x08 /* Private */,
       5,    2,   53,    2, 0x08 /* Private */,
       8,    1,   58,    2, 0x08 /* Private */,
      11,    1,   61,    2, 0x08 /* Private */,
      14,    0,   64,    2, 0x08 /* Private */,
      15,    0,   65,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 6,    4,    7,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void QProcess_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QProcess_hook *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->started_hook(); break;
        case 1: _t->finished_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->finished2_hook((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        case 3: _t->error_hook((*reinterpret_cast< QProcess::ProcessError(*)>(_a[1]))); break;
        case 4: _t->stateChanged_hook((*reinterpret_cast< QProcess::ProcessState(*)>(_a[1]))); break;
        case 5: _t->readyReadStandardOutput_hook(); break;
        case 6: _t->readyReadStandardError_hook(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QProcess_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QIODevice_hook::staticMetaObject>(),
    qt_meta_stringdata_QProcess_hook.data,
    qt_meta_data_QProcess_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QProcess_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QProcess_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QProcess_hook.stringdata0))
        return static_cast<void*>(this);
    return QIODevice_hook::qt_metacast(_clname);
}

int QProcess_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QIODevice_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
