/****************************************************************************
** Meta object code from reading C++ file 'qdockwidget_hook.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/qdockwidget_hook.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qdockwidget_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QDockWidget_hook_t {
    QByteArrayData data[15];
    char stringdata0[248];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QDockWidget_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QDockWidget_hook_t qt_meta_stringdata_QDockWidget_hook = {
    {
QT_MOC_LITERAL(0, 0, 16), // "QDockWidget_hook"
QT_MOC_LITERAL(1, 17, 20), // "featuresChanged_hook"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 31), // "QDockWidget::DockWidgetFeatures"
QT_MOC_LITERAL(4, 71, 8), // "features"
QT_MOC_LITERAL(5, 80, 20), // "topLevelChanged_hook"
QT_MOC_LITERAL(6, 101, 8), // "topLevel"
QT_MOC_LITERAL(7, 110, 24), // "allowedAreasChanged_hook"
QT_MOC_LITERAL(8, 135, 19), // "Qt::DockWidgetAreas"
QT_MOC_LITERAL(9, 155, 12), // "allowedAreas"
QT_MOC_LITERAL(10, 168, 22), // "visibilityChanged_hook"
QT_MOC_LITERAL(11, 191, 7), // "visible"
QT_MOC_LITERAL(12, 199, 24), // "dockLocationChanged_hook"
QT_MOC_LITERAL(13, 224, 18), // "Qt::DockWidgetArea"
QT_MOC_LITERAL(14, 243, 4) // "area"

    },
    "QDockWidget_hook\0featuresChanged_hook\0"
    "\0QDockWidget::DockWidgetFeatures\0"
    "features\0topLevelChanged_hook\0topLevel\0"
    "allowedAreasChanged_hook\0Qt::DockWidgetAreas\0"
    "allowedAreas\0visibilityChanged_hook\0"
    "visible\0dockLocationChanged_hook\0"
    "Qt::DockWidgetArea\0area"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QDockWidget_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x08 /* Private */,
       5,    1,   42,    2, 0x08 /* Private */,
       7,    1,   45,    2, 0x08 /* Private */,
      10,    1,   48,    2, 0x08 /* Private */,
      12,    1,   51,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::Bool,   11,
    QMetaType::Void, 0x80000000 | 13,   14,

       0        // eod
};

void QDockWidget_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QDockWidget_hook *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->featuresChanged_hook((*reinterpret_cast< QDockWidget::DockWidgetFeatures(*)>(_a[1]))); break;
        case 1: _t->topLevelChanged_hook((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->allowedAreasChanged_hook((*reinterpret_cast< Qt::DockWidgetAreas(*)>(_a[1]))); break;
        case 3: _t->visibilityChanged_hook((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->dockLocationChanged_hook((*reinterpret_cast< Qt::DockWidgetArea(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QDockWidget_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget_hook::staticMetaObject>(),
    qt_meta_stringdata_QDockWidget_hook.data,
    qt_meta_data_QDockWidget_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QDockWidget_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QDockWidget_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QDockWidget_hook.stringdata0))
        return static_cast<void*>(this);
    return QWidget_hook::qt_metacast(_clname);
}

int QDockWidget_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
