/****************************************************************************
** Meta object code from reading C++ file 'qscreen_hook.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/qscreen_hook.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qscreen_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QScreen_hook_t {
    QByteArrayData data[17];
    char stringdata0[319];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QScreen_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QScreen_hook_t qt_meta_stringdata_QScreen_hook = {
    {
QT_MOC_LITERAL(0, 0, 12), // "QScreen_hook"
QT_MOC_LITERAL(1, 13, 20), // "geometryChanged_hook"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 4), // "geom"
QT_MOC_LITERAL(4, 40, 29), // "availableGeometryChanged_hook"
QT_MOC_LITERAL(5, 70, 24), // "physicalSizeChanged_hook"
QT_MOC_LITERAL(6, 95, 3), // "pos"
QT_MOC_LITERAL(7, 99, 31), // "physicalDotsPerInchChanged_hook"
QT_MOC_LITERAL(8, 131, 3), // "dpi"
QT_MOC_LITERAL(9, 135, 30), // "logicalDotsPerInchChanged_hook"
QT_MOC_LITERAL(10, 166, 27), // "virtualGeometryChanged_hook"
QT_MOC_LITERAL(11, 194, 30), // "primaryOrientationChanged_hook"
QT_MOC_LITERAL(12, 225, 21), // "Qt::ScreenOrientation"
QT_MOC_LITERAL(13, 247, 11), // "orientation"
QT_MOC_LITERAL(14, 259, 23), // "orientationChanged_hook"
QT_MOC_LITERAL(15, 283, 23), // "refreshRateChanged_hook"
QT_MOC_LITERAL(16, 307, 11) // "refreshRate"

    },
    "QScreen_hook\0geometryChanged_hook\0\0"
    "geom\0availableGeometryChanged_hook\0"
    "physicalSizeChanged_hook\0pos\0"
    "physicalDotsPerInchChanged_hook\0dpi\0"
    "logicalDotsPerInchChanged_hook\0"
    "virtualGeometryChanged_hook\0"
    "primaryOrientationChanged_hook\0"
    "Qt::ScreenOrientation\0orientation\0"
    "orientationChanged_hook\0refreshRateChanged_hook\0"
    "refreshRate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QScreen_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x08 /* Private */,
       4,    1,   62,    2, 0x08 /* Private */,
       5,    1,   65,    2, 0x08 /* Private */,
       7,    1,   68,    2, 0x08 /* Private */,
       9,    1,   71,    2, 0x08 /* Private */,
      10,    1,   74,    2, 0x08 /* Private */,
      11,    1,   77,    2, 0x08 /* Private */,
      14,    1,   80,    2, 0x08 /* Private */,
      15,    1,   83,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QRect,    3,
    QMetaType::Void, QMetaType::QRect,    3,
    QMetaType::Void, QMetaType::QSizeF,    6,
    QMetaType::Void, QMetaType::QReal,    8,
    QMetaType::Void, QMetaType::QReal,    8,
    QMetaType::Void, QMetaType::QRect,    3,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, QMetaType::QReal,   16,

       0        // eod
};

void QScreen_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QScreen_hook *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->geometryChanged_hook((*reinterpret_cast< const QRect(*)>(_a[1]))); break;
        case 1: _t->availableGeometryChanged_hook((*reinterpret_cast< const QRect(*)>(_a[1]))); break;
        case 2: _t->physicalSizeChanged_hook((*reinterpret_cast< const QSizeF(*)>(_a[1]))); break;
        case 3: _t->physicalDotsPerInchChanged_hook((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 4: _t->logicalDotsPerInchChanged_hook((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 5: _t->virtualGeometryChanged_hook((*reinterpret_cast< const QRect(*)>(_a[1]))); break;
        case 6: _t->primaryOrientationChanged_hook((*reinterpret_cast< Qt::ScreenOrientation(*)>(_a[1]))); break;
        case 7: _t->orientationChanged_hook((*reinterpret_cast< Qt::ScreenOrientation(*)>(_a[1]))); break;
        case 8: _t->refreshRateChanged_hook((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QScreen_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_meta_stringdata_QScreen_hook.data,
    qt_meta_data_QScreen_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QScreen_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QScreen_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QScreen_hook.stringdata0))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QScreen_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
