/****************************************************************************
** Meta object code from reading C++ file 'qwindow_hook.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/qwindow_hook.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwindow_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QWindow_hook_t {
    QByteArrayData data[34];
    char stringdata0[568];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QWindow_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QWindow_hook_t qt_meta_stringdata_QWindow_hook = {
    {
QT_MOC_LITERAL(0, 0, 12), // "QWindow_hook"
QT_MOC_LITERAL(1, 13, 18), // "screenChanged_hook"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 8), // "QScreen*"
QT_MOC_LITERAL(4, 42, 6), // "screen"
QT_MOC_LITERAL(5, 49, 20), // "modalityChanged_hook"
QT_MOC_LITERAL(6, 70, 18), // "Qt::WindowModality"
QT_MOC_LITERAL(7, 89, 8), // "modality"
QT_MOC_LITERAL(8, 98, 23), // "windowStateChanged_hook"
QT_MOC_LITERAL(9, 122, 15), // "Qt::WindowState"
QT_MOC_LITERAL(10, 138, 11), // "windowState"
QT_MOC_LITERAL(11, 150, 23), // "windowTitleChanged_hook"
QT_MOC_LITERAL(12, 174, 5), // "title"
QT_MOC_LITERAL(13, 180, 13), // "xChanged_hook"
QT_MOC_LITERAL(14, 194, 3), // "arg"
QT_MOC_LITERAL(15, 198, 13), // "yChanged_hook"
QT_MOC_LITERAL(16, 212, 17), // "widthChanged_hook"
QT_MOC_LITERAL(17, 230, 18), // "heightChanged_hook"
QT_MOC_LITERAL(18, 249, 24), // "minimumWidthChanged_hook"
QT_MOC_LITERAL(19, 274, 25), // "minimumHeightChanged_hook"
QT_MOC_LITERAL(20, 300, 24), // "maximumWidthChanged_hook"
QT_MOC_LITERAL(21, 325, 25), // "maximumHeightChanged_hook"
QT_MOC_LITERAL(22, 351, 19), // "visibleChanged_hook"
QT_MOC_LITERAL(23, 371, 22), // "visibilityChanged_hook"
QT_MOC_LITERAL(24, 394, 19), // "QWindow::Visibility"
QT_MOC_LITERAL(25, 414, 10), // "visibility"
QT_MOC_LITERAL(26, 425, 18), // "activeChanged_hook"
QT_MOC_LITERAL(27, 444, 30), // "contentOrientationChanged_hook"
QT_MOC_LITERAL(28, 475, 21), // "Qt::ScreenOrientation"
QT_MOC_LITERAL(29, 497, 11), // "orientation"
QT_MOC_LITERAL(30, 509, 23), // "focusObjectChanged_hook"
QT_MOC_LITERAL(31, 533, 6), // "object"
QT_MOC_LITERAL(32, 540, 19), // "opacityChanged_hook"
QT_MOC_LITERAL(33, 560, 7) // "opacity"

    },
    "QWindow_hook\0screenChanged_hook\0\0"
    "QScreen*\0screen\0modalityChanged_hook\0"
    "Qt::WindowModality\0modality\0"
    "windowStateChanged_hook\0Qt::WindowState\0"
    "windowState\0windowTitleChanged_hook\0"
    "title\0xChanged_hook\0arg\0yChanged_hook\0"
    "widthChanged_hook\0heightChanged_hook\0"
    "minimumWidthChanged_hook\0"
    "minimumHeightChanged_hook\0"
    "maximumWidthChanged_hook\0"
    "maximumHeightChanged_hook\0visibleChanged_hook\0"
    "visibilityChanged_hook\0QWindow::Visibility\0"
    "visibility\0activeChanged_hook\0"
    "contentOrientationChanged_hook\0"
    "Qt::ScreenOrientation\0orientation\0"
    "focusObjectChanged_hook\0object\0"
    "opacityChanged_hook\0opacity"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QWindow_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,  104,    2, 0x08 /* Private */,
       5,    1,  107,    2, 0x08 /* Private */,
       8,    1,  110,    2, 0x08 /* Private */,
      11,    1,  113,    2, 0x08 /* Private */,
      13,    1,  116,    2, 0x08 /* Private */,
      15,    1,  119,    2, 0x08 /* Private */,
      16,    1,  122,    2, 0x08 /* Private */,
      17,    1,  125,    2, 0x08 /* Private */,
      18,    1,  128,    2, 0x08 /* Private */,
      19,    1,  131,    2, 0x08 /* Private */,
      20,    1,  134,    2, 0x08 /* Private */,
      21,    1,  137,    2, 0x08 /* Private */,
      22,    1,  140,    2, 0x08 /* Private */,
      23,    1,  143,    2, 0x08 /* Private */,
      26,    0,  146,    2, 0x08 /* Private */,
      27,    1,  147,    2, 0x08 /* Private */,
      30,    1,  150,    2, 0x08 /* Private */,
      32,    1,  153,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void, 0x80000000 | 24,   25,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 28,   29,
    QMetaType::Void, QMetaType::QObjectStar,   31,
    QMetaType::Void, QMetaType::QReal,   33,

       0        // eod
};

void QWindow_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QWindow_hook *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->screenChanged_hook((*reinterpret_cast< QScreen*(*)>(_a[1]))); break;
        case 1: _t->modalityChanged_hook((*reinterpret_cast< Qt::WindowModality(*)>(_a[1]))); break;
        case 2: _t->windowStateChanged_hook((*reinterpret_cast< Qt::WindowState(*)>(_a[1]))); break;
        case 3: _t->windowTitleChanged_hook((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->xChanged_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->yChanged_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->widthChanged_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->heightChanged_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->minimumWidthChanged_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->minimumHeightChanged_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->maximumWidthChanged_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->maximumHeightChanged_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->visibleChanged_hook((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->visibilityChanged_hook((*reinterpret_cast< QWindow::Visibility(*)>(_a[1]))); break;
        case 14: _t->activeChanged_hook(); break;
        case 15: _t->contentOrientationChanged_hook((*reinterpret_cast< Qt::ScreenOrientation(*)>(_a[1]))); break;
        case 16: _t->focusObjectChanged_hook((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 17: _t->opacityChanged_hook((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScreen* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QWindow_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_meta_stringdata_QWindow_hook.data,
    qt_meta_data_QWindow_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QWindow_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWindow_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QWindow_hook.stringdata0))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QWindow_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
