/****************************************************************************
** Meta object code from reading C++ file 'qplaintextedit_hook.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/qplaintextedit_hook.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qplaintextedit_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QPlainTextEdit_hook_t {
    QByteArrayData data[16];
    char stringdata0[246];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QPlainTextEdit_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QPlainTextEdit_hook_t qt_meta_stringdata_QPlainTextEdit_hook = {
    {
QT_MOC_LITERAL(0, 0, 19), // "QPlainTextEdit_hook"
QT_MOC_LITERAL(1, 20, 16), // "textChanged_hook"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 18), // "undoAvailable_hook"
QT_MOC_LITERAL(4, 57, 1), // "b"
QT_MOC_LITERAL(5, 59, 18), // "redoAvailable_hook"
QT_MOC_LITERAL(6, 78, 18), // "copyAvailable_hook"
QT_MOC_LITERAL(7, 97, 21), // "selectionChanged_hook"
QT_MOC_LITERAL(8, 119, 26), // "cursorPositionChanged_hook"
QT_MOC_LITERAL(9, 146, 18), // "updateRequest_hook"
QT_MOC_LITERAL(10, 165, 4), // "rect"
QT_MOC_LITERAL(11, 170, 2), // "dy"
QT_MOC_LITERAL(12, 173, 22), // "blockCountChanged_hook"
QT_MOC_LITERAL(13, 196, 13), // "newBlockCount"
QT_MOC_LITERAL(14, 210, 24), // "modificationChanged_hook"
QT_MOC_LITERAL(15, 235, 10) // "AnonParam1"

    },
    "QPlainTextEdit_hook\0textChanged_hook\0"
    "\0undoAvailable_hook\0b\0redoAvailable_hook\0"
    "copyAvailable_hook\0selectionChanged_hook\0"
    "cursorPositionChanged_hook\0"
    "updateRequest_hook\0rect\0dy\0"
    "blockCountChanged_hook\0newBlockCount\0"
    "modificationChanged_hook\0AnonParam1"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QPlainTextEdit_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x08 /* Private */,
       3,    1,   60,    2, 0x08 /* Private */,
       5,    1,   63,    2, 0x08 /* Private */,
       6,    1,   66,    2, 0x08 /* Private */,
       7,    0,   69,    2, 0x08 /* Private */,
       8,    0,   70,    2, 0x08 /* Private */,
       9,    2,   71,    2, 0x08 /* Private */,
      12,    1,   76,    2, 0x08 /* Private */,
      14,    1,   79,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QRect, QMetaType::Int,   10,   11,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::Bool,   15,

       0        // eod
};

void QPlainTextEdit_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QPlainTextEdit_hook *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->textChanged_hook(); break;
        case 1: _t->undoAvailable_hook((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->redoAvailable_hook((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->copyAvailable_hook((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->selectionChanged_hook(); break;
        case 5: _t->cursorPositionChanged_hook(); break;
        case 6: _t->updateRequest_hook((*reinterpret_cast< const QRect(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 7: _t->blockCountChanged_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->modificationChanged_hook((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QPlainTextEdit_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractScrollArea_hook::staticMetaObject>(),
    qt_meta_stringdata_QPlainTextEdit_hook.data,
    qt_meta_data_QPlainTextEdit_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QPlainTextEdit_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QPlainTextEdit_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QPlainTextEdit_hook.stringdata0))
        return static_cast<void*>(this);
    return QAbstractScrollArea_hook::qt_metacast(_clname);
}

int QPlainTextEdit_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractScrollArea_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}
struct qt_meta_stringdata_QPlainTextDocumentLayout_hook_t {
    QByteArrayData data[1];
    char stringdata0[30];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QPlainTextDocumentLayout_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QPlainTextDocumentLayout_hook_t qt_meta_stringdata_QPlainTextDocumentLayout_hook = {
    {
QT_MOC_LITERAL(0, 0, 29) // "QPlainTextDocumentLayout_hook"

    },
    "QPlainTextDocumentLayout_hook"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QPlainTextDocumentLayout_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QPlainTextDocumentLayout_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QPlainTextDocumentLayout_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractTextDocumentLayout_hook::staticMetaObject>(),
    qt_meta_stringdata_QPlainTextDocumentLayout_hook.data,
    qt_meta_data_QPlainTextDocumentLayout_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QPlainTextDocumentLayout_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QPlainTextDocumentLayout_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QPlainTextDocumentLayout_hook.stringdata0))
        return static_cast<void*>(this);
    return QAbstractTextDocumentLayout_hook::qt_metacast(_clname);
}

int QPlainTextDocumentLayout_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractTextDocumentLayout_hook::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
