/****************************************************************************
** Meta object code from reading C++ file 'qtreewidget_hook.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/qtreewidget_hook.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtreewidget_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QTreeWidgetItem_hook_t {
    QByteArrayData data[1];
    char stringdata0[21];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QTreeWidgetItem_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QTreeWidgetItem_hook_t qt_meta_stringdata_QTreeWidgetItem_hook = {
    {
QT_MOC_LITERAL(0, 0, 20) // "QTreeWidgetItem_hook"

    },
    "QTreeWidgetItem_hook"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QTreeWidgetItem_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QTreeWidgetItem_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QTreeWidgetItem_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_meta_stringdata_QTreeWidgetItem_hook.data,
    qt_meta_data_QTreeWidgetItem_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QTreeWidgetItem_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QTreeWidgetItem_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QTreeWidgetItem_hook.stringdata0))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QTreeWidgetItem_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_QTreeWidget_hook_t {
    QByteArrayData data[17];
    char stringdata0[261];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QTreeWidget_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QTreeWidget_hook_t qt_meta_stringdata_QTreeWidget_hook = {
    {
QT_MOC_LITERAL(0, 0, 16), // "QTreeWidget_hook"
QT_MOC_LITERAL(1, 17, 16), // "itemPressed_hook"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(4, 52, 4), // "item"
QT_MOC_LITERAL(5, 57, 6), // "column"
QT_MOC_LITERAL(6, 64, 16), // "itemClicked_hook"
QT_MOC_LITERAL(7, 81, 22), // "itemDoubleClicked_hook"
QT_MOC_LITERAL(8, 104, 18), // "itemActivated_hook"
QT_MOC_LITERAL(9, 123, 16), // "itemEntered_hook"
QT_MOC_LITERAL(10, 140, 16), // "itemChanged_hook"
QT_MOC_LITERAL(11, 157, 17), // "itemExpanded_hook"
QT_MOC_LITERAL(12, 175, 18), // "itemCollapsed_hook"
QT_MOC_LITERAL(13, 194, 23), // "currentItemChanged_hook"
QT_MOC_LITERAL(14, 218, 7), // "current"
QT_MOC_LITERAL(15, 226, 8), // "previous"
QT_MOC_LITERAL(16, 235, 25) // "itemSelectionChanged_hook"

    },
    "QTreeWidget_hook\0itemPressed_hook\0\0"
    "QTreeWidgetItem*\0item\0column\0"
    "itemClicked_hook\0itemDoubleClicked_hook\0"
    "itemActivated_hook\0itemEntered_hook\0"
    "itemChanged_hook\0itemExpanded_hook\0"
    "itemCollapsed_hook\0currentItemChanged_hook\0"
    "current\0previous\0itemSelectionChanged_hook"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QTreeWidget_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   64,    2, 0x08 /* Private */,
       6,    2,   69,    2, 0x08 /* Private */,
       7,    2,   74,    2, 0x08 /* Private */,
       8,    2,   79,    2, 0x08 /* Private */,
       9,    2,   84,    2, 0x08 /* Private */,
      10,    2,   89,    2, 0x08 /* Private */,
      11,    1,   94,    2, 0x08 /* Private */,
      12,    1,   97,    2, 0x08 /* Private */,
      13,    2,  100,    2, 0x08 /* Private */,
      16,    0,  105,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,    5,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,   14,   15,
    QMetaType::Void,

       0        // eod
};

void QTreeWidget_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QTreeWidget_hook *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->itemPressed_hook((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->itemClicked_hook((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->itemDoubleClicked_hook((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->itemActivated_hook((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->itemEntered_hook((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->itemChanged_hook((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 6: _t->itemExpanded_hook((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 7: _t->itemCollapsed_hook((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 8: _t->currentItemChanged_hook((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< QTreeWidgetItem*(*)>(_a[2]))); break;
        case 9: _t->itemSelectionChanged_hook(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QTreeWidget_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeView_hook::staticMetaObject>(),
    qt_meta_stringdata_QTreeWidget_hook.data,
    qt_meta_data_QTreeWidget_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QTreeWidget_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QTreeWidget_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QTreeWidget_hook.stringdata0))
        return static_cast<void*>(this);
    return QTreeView_hook::qt_metacast(_clname);
}

int QTreeWidget_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
