/****************************************************************************
** Meta object code from reading C++ file 'qlistwidget_hook.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/qlistwidget_hook.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qlistwidget_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QListWidgetItem_hook_t {
    QByteArrayData data[1];
    char stringdata0[21];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QListWidgetItem_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QListWidgetItem_hook_t qt_meta_stringdata_QListWidgetItem_hook = {
    {
QT_MOC_LITERAL(0, 0, 20) // "QListWidgetItem_hook"

    },
    "QListWidgetItem_hook"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QListWidgetItem_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QListWidgetItem_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QListWidgetItem_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_meta_stringdata_QListWidgetItem_hook.data,
    qt_meta_data_QListWidgetItem_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QListWidgetItem_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QListWidgetItem_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QListWidgetItem_hook.stringdata0))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QListWidgetItem_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_QListWidget_hook_t {
    QByteArrayData data[18];
    char stringdata0[287];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QListWidget_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QListWidget_hook_t qt_meta_stringdata_QListWidget_hook = {
    {
QT_MOC_LITERAL(0, 0, 16), // "QListWidget_hook"
QT_MOC_LITERAL(1, 17, 16), // "itemPressed_hook"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(4, 52, 4), // "item"
QT_MOC_LITERAL(5, 57, 16), // "itemClicked_hook"
QT_MOC_LITERAL(6, 74, 22), // "itemDoubleClicked_hook"
QT_MOC_LITERAL(7, 97, 18), // "itemActivated_hook"
QT_MOC_LITERAL(8, 116, 16), // "itemEntered_hook"
QT_MOC_LITERAL(9, 133, 16), // "itemChanged_hook"
QT_MOC_LITERAL(10, 150, 23), // "currentItemChanged_hook"
QT_MOC_LITERAL(11, 174, 7), // "current"
QT_MOC_LITERAL(12, 182, 8), // "previous"
QT_MOC_LITERAL(13, 191, 23), // "currentTextChanged_hook"
QT_MOC_LITERAL(14, 215, 11), // "currentText"
QT_MOC_LITERAL(15, 227, 22), // "currentRowChanged_hook"
QT_MOC_LITERAL(16, 250, 10), // "currentRow"
QT_MOC_LITERAL(17, 261, 25) // "itemSelectionChanged_hook"

    },
    "QListWidget_hook\0itemPressed_hook\0\0"
    "QListWidgetItem*\0item\0itemClicked_hook\0"
    "itemDoubleClicked_hook\0itemActivated_hook\0"
    "itemEntered_hook\0itemChanged_hook\0"
    "currentItemChanged_hook\0current\0"
    "previous\0currentTextChanged_hook\0"
    "currentText\0currentRowChanged_hook\0"
    "currentRow\0itemSelectionChanged_hook"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QListWidget_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x08 /* Private */,
       5,    1,   67,    2, 0x08 /* Private */,
       6,    1,   70,    2, 0x08 /* Private */,
       7,    1,   73,    2, 0x08 /* Private */,
       8,    1,   76,    2, 0x08 /* Private */,
       9,    1,   79,    2, 0x08 /* Private */,
      10,    2,   82,    2, 0x08 /* Private */,
      13,    1,   87,    2, 0x08 /* Private */,
      15,    1,   90,    2, 0x08 /* Private */,
      17,    0,   93,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,   11,   12,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, QMetaType::Int,   16,
    QMetaType::Void,

       0        // eod
};

void QListWidget_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QListWidget_hook *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->itemPressed_hook((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 1: _t->itemClicked_hook((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 2: _t->itemDoubleClicked_hook((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 3: _t->itemActivated_hook((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 4: _t->itemEntered_hook((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 5: _t->itemChanged_hook((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 6: _t->currentItemChanged_hook((*reinterpret_cast< QListWidgetItem*(*)>(_a[1])),(*reinterpret_cast< QListWidgetItem*(*)>(_a[2]))); break;
        case 7: _t->currentTextChanged_hook((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->currentRowChanged_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->itemSelectionChanged_hook(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QListWidget_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QListView_hook::staticMetaObject>(),
    qt_meta_stringdata_QListWidget_hook.data,
    qt_meta_data_QListWidget_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QListWidget_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QListWidget_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QListWidget_hook.stringdata0))
        return static_cast<void*>(this);
    return QListView_hook::qt_metacast(_clname);
}

int QListWidget_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QListView_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
