/****************************************************************************
** Meta object code from reading C++ file 'qcombobox_hook.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/qcombobox_hook.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qcombobox_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QComboBox_hook_t {
    QByteArrayData data[12];
    char stringdata0[195];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QComboBox_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QComboBox_hook_t qt_meta_stringdata_QComboBox_hook = {
    {
QT_MOC_LITERAL(0, 0, 14), // "QComboBox_hook"
QT_MOC_LITERAL(1, 15, 20), // "editTextChanged_hook"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 10), // "AnonParam1"
QT_MOC_LITERAL(4, 48, 14), // "activated_hook"
QT_MOC_LITERAL(5, 63, 5), // "index"
QT_MOC_LITERAL(6, 69, 15), // "activated2_hook"
QT_MOC_LITERAL(7, 85, 16), // "highlighted_hook"
QT_MOC_LITERAL(8, 102, 17), // "highlighted2_hook"
QT_MOC_LITERAL(9, 120, 24), // "currentIndexChanged_hook"
QT_MOC_LITERAL(10, 145, 25), // "currentIndexChanged2_hook"
QT_MOC_LITERAL(11, 171, 23) // "currentTextChanged_hook"

    },
    "QComboBox_hook\0editTextChanged_hook\0"
    "\0AnonParam1\0activated_hook\0index\0"
    "activated2_hook\0highlighted_hook\0"
    "highlighted2_hook\0currentIndexChanged_hook\0"
    "currentIndexChanged2_hook\0"
    "currentTextChanged_hook"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QComboBox_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x08 /* Private */,
       4,    1,   57,    2, 0x08 /* Private */,
       6,    1,   60,    2, 0x08 /* Private */,
       7,    1,   63,    2, 0x08 /* Private */,
       8,    1,   66,    2, 0x08 /* Private */,
       9,    1,   69,    2, 0x08 /* Private */,
      10,    1,   72,    2, 0x08 /* Private */,
      11,    1,   75,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,

       0        // eod
};

void QComboBox_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QComboBox_hook *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->editTextChanged_hook((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->activated_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->activated2_hook((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->highlighted_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->highlighted2_hook((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->currentIndexChanged_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->currentIndexChanged2_hook((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->currentTextChanged_hook((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QComboBox_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget_hook::staticMetaObject>(),
    qt_meta_stringdata_QComboBox_hook.data,
    qt_meta_data_QComboBox_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QComboBox_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QComboBox_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QComboBox_hook.stringdata0))
        return static_cast<void*>(this);
    return QWidget_hook::qt_metacast(_clname);
}

int QComboBox_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
