/****************************************************************************
** Meta object code from reading C++ file 'qheaderview_hook.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/qheaderview_hook.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qheaderview_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QHeaderView_hook_t {
    QByteArrayData data[21];
    char stringdata0[345];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QHeaderView_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QHeaderView_hook_t qt_meta_stringdata_QHeaderView_hook = {
    {
QT_MOC_LITERAL(0, 0, 16), // "QHeaderView_hook"
QT_MOC_LITERAL(1, 17, 17), // "sectionMoved_hook"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 12), // "logicalIndex"
QT_MOC_LITERAL(4, 49, 14), // "oldVisualIndex"
QT_MOC_LITERAL(5, 64, 14), // "newVisualIndex"
QT_MOC_LITERAL(6, 79, 19), // "sectionResized_hook"
QT_MOC_LITERAL(7, 99, 7), // "oldSize"
QT_MOC_LITERAL(8, 107, 7), // "newSize"
QT_MOC_LITERAL(9, 115, 19), // "sectionPressed_hook"
QT_MOC_LITERAL(10, 135, 19), // "sectionClicked_hook"
QT_MOC_LITERAL(11, 155, 19), // "sectionEntered_hook"
QT_MOC_LITERAL(12, 175, 25), // "sectionDoubleClicked_hook"
QT_MOC_LITERAL(13, 201, 24), // "sectionCountChanged_hook"
QT_MOC_LITERAL(14, 226, 8), // "oldCount"
QT_MOC_LITERAL(15, 235, 8), // "newCount"
QT_MOC_LITERAL(16, 244, 31), // "sectionHandleDoubleClicked_hook"
QT_MOC_LITERAL(17, 276, 22), // "geometriesChanged_hook"
QT_MOC_LITERAL(18, 299, 25), // "sortIndicatorChanged_hook"
QT_MOC_LITERAL(19, 325, 13), // "Qt::SortOrder"
QT_MOC_LITERAL(20, 339, 5) // "order"

    },
    "QHeaderView_hook\0sectionMoved_hook\0\0"
    "logicalIndex\0oldVisualIndex\0newVisualIndex\0"
    "sectionResized_hook\0oldSize\0newSize\0"
    "sectionPressed_hook\0sectionClicked_hook\0"
    "sectionEntered_hook\0sectionDoubleClicked_hook\0"
    "sectionCountChanged_hook\0oldCount\0"
    "newCount\0sectionHandleDoubleClicked_hook\0"
    "geometriesChanged_hook\0sortIndicatorChanged_hook\0"
    "Qt::SortOrder\0order"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QHeaderView_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    3,   64,    2, 0x08 /* Private */,
       6,    3,   71,    2, 0x08 /* Private */,
       9,    1,   78,    2, 0x08 /* Private */,
      10,    1,   81,    2, 0x08 /* Private */,
      11,    1,   84,    2, 0x08 /* Private */,
      12,    1,   87,    2, 0x08 /* Private */,
      13,    2,   90,    2, 0x08 /* Private */,
      16,    1,   95,    2, 0x08 /* Private */,
      17,    0,   98,    2, 0x08 /* Private */,
      18,    2,   99,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    7,    8,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   14,   15,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 19,    3,   20,

       0        // eod
};

void QHeaderView_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QHeaderView_hook *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->sectionMoved_hook((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 1: _t->sectionResized_hook((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 2: _t->sectionPressed_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->sectionClicked_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->sectionEntered_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->sectionDoubleClicked_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->sectionCountChanged_hook((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 7: _t->sectionHandleDoubleClicked_hook((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->geometriesChanged_hook(); break;
        case 9: _t->sortIndicatorChanged_hook((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Qt::SortOrder(*)>(_a[2]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QHeaderView_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemView_hook::staticMetaObject>(),
    qt_meta_stringdata_QHeaderView_hook.data,
    qt_meta_data_QHeaderView_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QHeaderView_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QHeaderView_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QHeaderView_hook.stringdata0))
        return static_cast<void*>(this);
    return QAbstractItemView_hook::qt_metacast(_clname);
}

int QHeaderView_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemView_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
