/****************************************************************************
** Meta object code from reading C++ file 'qguiapplication_hook.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/qguiapplication_hook.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qguiapplication_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QGuiApplication_hook_t {
    QByteArrayData data[18];
    char stringdata0[305];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QGuiApplication_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QGuiApplication_hook_t qt_meta_stringdata_QGuiApplication_hook = {
    {
QT_MOC_LITERAL(0, 0, 20), // "QGuiApplication_hook"
QT_MOC_LITERAL(1, 21, 24), // "fontDatabaseChanged_hook"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 16), // "screenAdded_hook"
QT_MOC_LITERAL(4, 64, 8), // "QScreen*"
QT_MOC_LITERAL(5, 73, 6), // "screen"
QT_MOC_LITERAL(6, 80, 18), // "screenRemoved_hook"
QT_MOC_LITERAL(7, 99, 25), // "primaryScreenChanged_hook"
QT_MOC_LITERAL(8, 125, 21), // "lastWindowClosed_hook"
QT_MOC_LITERAL(9, 147, 23), // "focusObjectChanged_hook"
QT_MOC_LITERAL(10, 171, 11), // "focusObject"
QT_MOC_LITERAL(11, 183, 23), // "focusWindowChanged_hook"
QT_MOC_LITERAL(12, 207, 8), // "QWindow*"
QT_MOC_LITERAL(13, 216, 11), // "focusWindow"
QT_MOC_LITERAL(14, 228, 22), // "commitDataRequest_hook"
QT_MOC_LITERAL(15, 251, 16), // "QSessionManager&"
QT_MOC_LITERAL(16, 268, 14), // "sessionManager"
QT_MOC_LITERAL(17, 283, 21) // "saveStateRequest_hook"

    },
    "QGuiApplication_hook\0fontDatabaseChanged_hook\0"
    "\0screenAdded_hook\0QScreen*\0screen\0"
    "screenRemoved_hook\0primaryScreenChanged_hook\0"
    "lastWindowClosed_hook\0focusObjectChanged_hook\0"
    "focusObject\0focusWindowChanged_hook\0"
    "QWindow*\0focusWindow\0commitDataRequest_hook\0"
    "QSessionManager&\0sessionManager\0"
    "saveStateRequest_hook"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QGuiApplication_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x08 /* Private */,
       3,    1,   60,    2, 0x08 /* Private */,
       6,    1,   63,    2, 0x08 /* Private */,
       7,    1,   66,    2, 0x08 /* Private */,
       8,    0,   69,    2, 0x08 /* Private */,
       9,    1,   70,    2, 0x08 /* Private */,
      11,    1,   73,    2, 0x08 /* Private */,
      14,    1,   76,    2, 0x08 /* Private */,
      17,    1,   79,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QObjectStar,   10,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void, 0x80000000 | 15,   16,

       0        // eod
};

void QGuiApplication_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QGuiApplication_hook *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->fontDatabaseChanged_hook(); break;
        case 1: _t->screenAdded_hook((*reinterpret_cast< QScreen*(*)>(_a[1]))); break;
        case 2: _t->screenRemoved_hook((*reinterpret_cast< QScreen*(*)>(_a[1]))); break;
        case 3: _t->primaryScreenChanged_hook((*reinterpret_cast< QScreen*(*)>(_a[1]))); break;
        case 4: _t->lastWindowClosed_hook(); break;
        case 5: _t->focusObjectChanged_hook((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 6: _t->focusWindowChanged_hook((*reinterpret_cast< QWindow*(*)>(_a[1]))); break;
        case 7: _t->commitDataRequest_hook((*reinterpret_cast< QSessionManager(*)>(_a[1]))); break;
        case 8: _t->saveStateRequest_hook((*reinterpret_cast< QSessionManager(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScreen* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScreen* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScreen* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWindow* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QGuiApplication_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QCoreApplication_hook::staticMetaObject>(),
    qt_meta_stringdata_QGuiApplication_hook.data,
    qt_meta_data_QGuiApplication_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QGuiApplication_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QGuiApplication_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QGuiApplication_hook.stringdata0))
        return static_cast<void*>(this);
    return QCoreApplication_hook::qt_metacast(_clname);
}

int QGuiApplication_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QCoreApplication_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
