/****************************************************************************
** Meta object code from reading C++ file 'qabstractitemmodel_hook.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/qabstractitemmodel_hook.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qabstractitemmodel_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QModelIndex_hook_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QModelIndex_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QModelIndex_hook_t qt_meta_stringdata_QModelIndex_hook = {
    {
QT_MOC_LITERAL(0, 0, 16) // "QModelIndex_hook"

    },
    "QModelIndex_hook"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QModelIndex_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QModelIndex_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QModelIndex_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_meta_stringdata_QModelIndex_hook.data,
    qt_meta_data_QModelIndex_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QModelIndex_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QModelIndex_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QModelIndex_hook.stringdata0))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QModelIndex_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_QPersistentModelIndex_hook_t {
    QByteArrayData data[1];
    char stringdata0[27];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QPersistentModelIndex_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QPersistentModelIndex_hook_t qt_meta_stringdata_QPersistentModelIndex_hook = {
    {
QT_MOC_LITERAL(0, 0, 26) // "QPersistentModelIndex_hook"

    },
    "QPersistentModelIndex_hook"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QPersistentModelIndex_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QPersistentModelIndex_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QPersistentModelIndex_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_meta_stringdata_QPersistentModelIndex_hook.data,
    qt_meta_data_QPersistentModelIndex_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QPersistentModelIndex_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QPersistentModelIndex_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QPersistentModelIndex_hook.stringdata0))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QPersistentModelIndex_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_QAbstractItemModel_hook_t {
    QByteArrayData data[39];
    char stringdata0[622];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QAbstractItemModel_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QAbstractItemModel_hook_t qt_meta_stringdata_QAbstractItemModel_hook = {
    {
QT_MOC_LITERAL(0, 0, 23), // "QAbstractItemModel_hook"
QT_MOC_LITERAL(1, 24, 16), // "dataChanged_hook"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 11), // "QModelIndex"
QT_MOC_LITERAL(4, 54, 7), // "topLeft"
QT_MOC_LITERAL(5, 62, 11), // "bottomRight"
QT_MOC_LITERAL(6, 74, 22), // "headerDataChanged_hook"
QT_MOC_LITERAL(7, 97, 15), // "Qt::Orientation"
QT_MOC_LITERAL(8, 113, 11), // "orientation"
QT_MOC_LITERAL(9, 125, 5), // "first"
QT_MOC_LITERAL(10, 131, 4), // "last"
QT_MOC_LITERAL(11, 136, 18), // "layoutChanged_hook"
QT_MOC_LITERAL(12, 155, 27), // "layoutAboutToBeChanged_hook"
QT_MOC_LITERAL(13, 183, 26), // "rowsAboutToBeInserted_hook"
QT_MOC_LITERAL(14, 210, 6), // "parent"
QT_MOC_LITERAL(15, 217, 17), // "rowsInserted_hook"
QT_MOC_LITERAL(16, 235, 25), // "rowsAboutToBeRemoved_hook"
QT_MOC_LITERAL(17, 261, 16), // "rowsRemoved_hook"
QT_MOC_LITERAL(18, 278, 29), // "columnsAboutToBeInserted_hook"
QT_MOC_LITERAL(19, 308, 20), // "columnsInserted_hook"
QT_MOC_LITERAL(20, 329, 28), // "columnsAboutToBeRemoved_hook"
QT_MOC_LITERAL(21, 358, 19), // "columnsRemoved_hook"
QT_MOC_LITERAL(22, 378, 24), // "modelAboutToBeReset_hook"
QT_MOC_LITERAL(23, 403, 15), // "modelReset_hook"
QT_MOC_LITERAL(24, 419, 23), // "rowsAboutToBeMoved_hook"
QT_MOC_LITERAL(25, 443, 12), // "sourceParent"
QT_MOC_LITERAL(26, 456, 11), // "sourceStart"
QT_MOC_LITERAL(27, 468, 9), // "sourceEnd"
QT_MOC_LITERAL(28, 478, 17), // "destinationParent"
QT_MOC_LITERAL(29, 496, 14), // "destinationRow"
QT_MOC_LITERAL(30, 511, 14), // "rowsMoved_hook"
QT_MOC_LITERAL(31, 526, 5), // "start"
QT_MOC_LITERAL(32, 532, 3), // "end"
QT_MOC_LITERAL(33, 536, 11), // "destination"
QT_MOC_LITERAL(34, 548, 3), // "row"
QT_MOC_LITERAL(35, 552, 26), // "columnsAboutToBeMoved_hook"
QT_MOC_LITERAL(36, 579, 17), // "destinationColumn"
QT_MOC_LITERAL(37, 597, 17), // "columnsMoved_hook"
QT_MOC_LITERAL(38, 615, 6) // "column"

    },
    "QAbstractItemModel_hook\0dataChanged_hook\0"
    "\0QModelIndex\0topLeft\0bottomRight\0"
    "headerDataChanged_hook\0Qt::Orientation\0"
    "orientation\0first\0last\0layoutChanged_hook\0"
    "layoutAboutToBeChanged_hook\0"
    "rowsAboutToBeInserted_hook\0parent\0"
    "rowsInserted_hook\0rowsAboutToBeRemoved_hook\0"
    "rowsRemoved_hook\0columnsAboutToBeInserted_hook\0"
    "columnsInserted_hook\0columnsAboutToBeRemoved_hook\0"
    "columnsRemoved_hook\0modelAboutToBeReset_hook\0"
    "modelReset_hook\0rowsAboutToBeMoved_hook\0"
    "sourceParent\0sourceStart\0sourceEnd\0"
    "destinationParent\0destinationRow\0"
    "rowsMoved_hook\0start\0end\0destination\0"
    "row\0columnsAboutToBeMoved_hook\0"
    "destinationColumn\0columnsMoved_hook\0"
    "column"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QAbstractItemModel_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,  104,    2, 0x08 /* Private */,
       6,    3,  109,    2, 0x08 /* Private */,
      11,    0,  116,    2, 0x08 /* Private */,
      12,    0,  117,    2, 0x08 /* Private */,
      13,    3,  118,    2, 0x08 /* Private */,
      15,    3,  125,    2, 0x08 /* Private */,
      16,    3,  132,    2, 0x08 /* Private */,
      17,    3,  139,    2, 0x08 /* Private */,
      18,    3,  146,    2, 0x08 /* Private */,
      19,    3,  153,    2, 0x08 /* Private */,
      20,    3,  160,    2, 0x08 /* Private */,
      21,    3,  167,    2, 0x08 /* Private */,
      22,    0,  174,    2, 0x08 /* Private */,
      23,    0,  175,    2, 0x08 /* Private */,
      24,    5,  176,    2, 0x08 /* Private */,
      30,    5,  187,    2, 0x08 /* Private */,
      35,    5,  198,    2, 0x08 /* Private */,
      37,    5,  209,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    4,    5,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int, QMetaType::Int,    8,    9,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   14,    9,   10,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   14,    9,   10,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   14,    9,   10,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   14,    9,   10,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   14,    9,   10,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   14,    9,   10,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   14,    9,   10,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   14,    9,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int, 0x80000000 | 3, QMetaType::Int,   25,   26,   27,   28,   29,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int, 0x80000000 | 3, QMetaType::Int,   14,   31,   32,   33,   34,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int, 0x80000000 | 3, QMetaType::Int,   25,   26,   27,   28,   36,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int, 0x80000000 | 3, QMetaType::Int,   14,   31,   32,   33,   38,

       0        // eod
};

void QAbstractItemModel_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QAbstractItemModel_hook *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->dataChanged_hook((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 1: _t->headerDataChanged_hook((*reinterpret_cast< Qt::Orientation(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 2: _t->layoutChanged_hook(); break;
        case 3: _t->layoutAboutToBeChanged_hook(); break;
        case 4: _t->rowsAboutToBeInserted_hook((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 5: _t->rowsInserted_hook((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 6: _t->rowsAboutToBeRemoved_hook((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 7: _t->rowsRemoved_hook((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 8: _t->columnsAboutToBeInserted_hook((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 9: _t->columnsInserted_hook((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 10: _t->columnsAboutToBeRemoved_hook((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 11: _t->columnsRemoved_hook((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 12: _t->modelAboutToBeReset_hook(); break;
        case 13: _t->modelReset_hook(); break;
        case 14: _t->rowsAboutToBeMoved_hook((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QModelIndex(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 15: _t->rowsMoved_hook((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QModelIndex(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 16: _t->columnsAboutToBeMoved_hook((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QModelIndex(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 17: _t->columnsMoved_hook((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QModelIndex(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QAbstractItemModel_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_meta_stringdata_QAbstractItemModel_hook.data,
    qt_meta_data_QAbstractItemModel_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QAbstractItemModel_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QAbstractItemModel_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QAbstractItemModel_hook.stringdata0))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QAbstractItemModel_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 18;
    }
    return _id;
}
struct qt_meta_stringdata_QAbstractTableModel_hook_t {
    QByteArrayData data[1];
    char stringdata0[25];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QAbstractTableModel_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QAbstractTableModel_hook_t qt_meta_stringdata_QAbstractTableModel_hook = {
    {
QT_MOC_LITERAL(0, 0, 24) // "QAbstractTableModel_hook"

    },
    "QAbstractTableModel_hook"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QAbstractTableModel_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QAbstractTableModel_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QAbstractTableModel_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel_hook::staticMetaObject>(),
    qt_meta_stringdata_QAbstractTableModel_hook.data,
    qt_meta_data_QAbstractTableModel_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QAbstractTableModel_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QAbstractTableModel_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QAbstractTableModel_hook.stringdata0))
        return static_cast<void*>(this);
    return QAbstractItemModel_hook::qt_metacast(_clname);
}

int QAbstractTableModel_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel_hook::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_QAbstractListModel_hook_t {
    QByteArrayData data[1];
    char stringdata0[24];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QAbstractListModel_hook_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QAbstractListModel_hook_t qt_meta_stringdata_QAbstractListModel_hook = {
    {
QT_MOC_LITERAL(0, 0, 23) // "QAbstractListModel_hook"

    },
    "QAbstractListModel_hook"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QAbstractListModel_hook[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QAbstractListModel_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QAbstractListModel_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel_hook::staticMetaObject>(),
    qt_meta_stringdata_QAbstractListModel_hook.data,
    qt_meta_data_QAbstractListModel_hook,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QAbstractListModel_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QAbstractListModel_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QAbstractListModel_hook.stringdata0))
        return static_cast<void*>(this);
    return QAbstractItemModel_hook::qt_metacast(_clname);
}

int QAbstractListModel_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel_hook::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
